@@ -337,13 +337,29 @@ class TimeToStr(Func):
     arg_types = {'this': True, 'format': True}
 
 
+class TimeToTimeStr(Func):
+    arg_types = {'this': True}
+
+
 class TimeToUnix(Func):
     arg_types = {'this': True}
 
 
+class TimeStrToTime(Func):
+    arg_types = {'this': True}
+
+
+class TimeStrToUnix(Func):
+    arg_types = {'this': True}
+
+
 class UnixToStr(Func):
     arg_types = {'this': True, 'format': True}
 
 
 class UnixToTime(Func):
     arg_types = {'this': True}
+
+
+class UnixToTimeStr(Func):
+    arg_types = {'this': True}
