@@ -24,10 +24,14 @@ class Parser:
         'IF': lambda args: exp.If(condition=args[0], true=args[1], false=args[2] if len(args) > 2 else None),
         'STR_TO_TIME': lambda args: exp.StrToTime(this=args[0], format=args[1]),
         'STR_TO_UNIX': lambda args: exp.StrToUnix(this=args[0], format=args[1]),
+        'TIME_STR_TO_TIME': lambda args: exp.TimeStrToTime(this=args[0]),
+        'TIME_STR_TO_UNIX': lambda args: exp.TimeStrToUnix(this=args[0]),
         'TIME_TO_STR': lambda args: exp.TimeToStr(this=args[0], format=args[1]),
+        'TIME_TO_TIME_STR': lambda args: exp.TimeToTimeStr(this=args[0]),
         'TIME_TO_UNIX': lambda args: exp.TimeToUnix(this=args[0]),
         'UNIX_TO_STR': lambda args: exp.UnixToStr(this=args[0], format=args[1]),
         'UNIX_TO_TIME': lambda args: exp.UnixToTime(this=args[0]),
+        'UNIX_TO_TIME_STR': lambda args: exp.UnixToTimeStr(this=args[0]),
     }
 
     TYPE_TOKENS = {
